#import "PokktCustomBanner.h"

@implementation PokktCustomBanner
@synthesize delegate;


#pragma mark Pokkt Banner Ads Request

- (void)requestBannerAd:(GADAdSize)adSize
              parameter:(NSString *)serverParameter
                  label:(NSString *)serverLabel
                request:(GADCustomEventRequest *)request
{
    if (serverParameter == nil)
    {
        return;
    }
    NSError *jsonError;
    NSData *objectData = [serverParameter dataUsingEncoding:NSUTF8StringEncoding];
    NSDictionary *json = [NSJSONSerialization JSONObjectWithData:objectData
                                                         options:NSJSONReadingMutableContainers
                                                           error:&jsonError];
    
    screenName = [json objectForKey:@"POKKT_SCREEN_NAME"];
    appId = [json objectForKey:@"POKKT_APP_ID"];
    securityKey = [json objectForKey:@"POKKT_SEC_KEY"];
    BOOL isDebug = [[json objectForKey:@"POKKT_DEBUG"] boolValue];
    NSString *thirdPartyId = [json objectForKey:@"POKKT_THIRD_PARTY_USERID"];
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional], set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];

    [PokktBanner setPokktBannerDelegate:self];
    
    banner_top = [PokktBanner initWithBannerAdSize:CGRectMake(0, 0, [UIScreen mainScreen].bounds.size.width, 50)];
    [banner_top setBackgroundColor:[UIColor lightGrayColor]];
    
    UIViewController *topVC = [self topViewController];
    [topVC.view addSubview:banner_top];
    
    [PokktBanner loadBanner:banner_top withScreenName:screenName rootViewContorller:topVC];
}


#pragma mark Pokkt Banner Ads Delegates


- (void)bannerLoaded:(NSString *)screenName
{
    [self.delegate customEventBanner:self didReceiveAd:banner_top];
}

- (void)bannerLoadFailed:(NSString *)screenName errorMessage:(NSString *)errorMessage
{
    NSError *err = [NSError errorWithDomain:@"some_domain"
                                       code:100
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];
    [self.delegate customEventBanner:self didFailAd:err];
}

- (UIViewController*)topViewController {
    return [self topViewControllerWithRootViewController:[UIApplication sharedApplication].keyWindow.rootViewController];
}

- (UIViewController*)topViewControllerWithRootViewController:(UIViewController*)rootViewController {
    if ([rootViewController isKindOfClass:[UITabBarController class]]) {
        UITabBarController* tabBarController = (UITabBarController*)rootViewController;
        return [self topViewControllerWithRootViewController:tabBarController.selectedViewController];
    } else if ([rootViewController isKindOfClass:[UINavigationController class]]) {
        UINavigationController* navigationController = (UINavigationController*)rootViewController;
        return [self topViewControllerWithRootViewController:navigationController.visibleViewController];
    } else if (rootViewController.presentedViewController) {
        UIViewController* presentedViewController = rootViewController.presentedViewController;
        return [self topViewControllerWithRootViewController:presentedViewController];
    } else {
        return rootViewController;
    }
}

@end
