#import "PokktCustomInterstitial.h"

@implementation PokktCustomInterstitial


@synthesize delegate;

#pragma mark Pokkt Video Ads Request

- (void)requestInterstitialAdWithParameter:(NSString *)serverParameter
                                     label:(NSString *)serverLabel
                                   request:(GADCustomEventRequest *)request
{
    
    if (serverParameter == nil)
    {
        return;
    }
    NSError *jsonError;
    NSData *objectData = [serverParameter dataUsingEncoding:NSUTF8StringEncoding];
    NSDictionary *json = [NSJSONSerialization JSONObjectWithData:objectData
                                                         options:NSJSONReadingMutableContainers
                                                           error:&jsonError];
    
    screenName = [json objectForKey:@"POKKT_SCREEN_NAME"];
    appId = [json objectForKey:@"POKKT_APP_ID"];
    securityKey = [json objectForKey:@"POKKT_SEC_KEY"];
    BOOL isDebug = [[json objectForKey:@"POKKT_DEBUG"] boolValue];
    NSString *thirdPartyId = [json objectForKey:@"POKKT_THIRD_PARTY_USERID"];

    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional] set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    
    // OPTIONAL but we SUGGEST you to implement delegates as it will help you to determine the status of your request
    
    [PokktVideoAds setPokktVideoAdsDelegate:self];
    [PokktInterstitial setPokktInterstitialDelegate:self];
    
    [PokktVideoAds cacheNonRewarded:screenName];

}


- (void)presentFromRootViewController:(UIViewController *)rootViewController
{
    if (adType == Interstitial_Ad)
    {
        [PokktInterstitial showNonRewarded:screenName withViewController:rootViewController];
    }
    else if (adType == Video_Ad)
    {
        [PokktVideoAds showNonRewarded:screenName withViewController:rootViewController];
    }
}

#pragma mark Pokkt Interstitial Ads Delegates

- (void)interstitialDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    [self.delegate customEventInterstitialWillPresent:self];
}


- (void)interstitialCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    adType = Interstitial_Ad;
    [self.delegate customEventInterstitialDidReceiveAd:self];
}

- (void)interstitialCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
     adType = No_Ad;
    NSError *err = [NSError errorWithDomain:@"Error"
                                       code:0
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];
    [self.delegate customEventInterstitial:self didFailAd:err];
}

- (void)interstitialClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
     adType = No_Ad;
   [self.delegate customEventInterstitialWillDismiss:self];
}

- (void)interstitialCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}

- (void)interstitialSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}

- (void)interstitialFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    
}


#pragma mark Pokkt Video Ads Delegates

- (void)videoAdCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    adType = Video_Ad;
    [self.delegate customEventInterstitialDidReceiveAd:self];
}

- (void)videoAdCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    adType = No_Ad;
   [PokktInterstitial cacheNonRewarded:screenName];
}

- (void)videoAdDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    [self.delegate customEventInterstitialWillPresent:self];
}

- (void)videoAdClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
    adType = No_Ad;
    [self.delegate customEventInterstitialWillDismiss:self];

}

- (void)videoAdFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    
}

- (void)videoAdCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}

- (void)videoAdSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    
}








@end
