#import "PokktCustomRewardedVideo.h"

@interface PokktCustomRewardedVideo () {
    /// Connector from Google Mobile Ads SDK to receive ad configurations.
    __weak id<GADMAdNetworkConnector> _connector;
    
    /// Connector from Google Mobile Ads SDK to receive reward-based video ad configurations.
    __weak id<GADMRewardBasedVideoAdNetworkConnector> _rewardBasedVideoAdConnector;
    
    NSString *pokktScreenName;
    NSString *appId;
    NSString *securityKey;
    BOOL isDebug;
    NSString *thirdPartyId;
    
}

@end

@implementation PokktCustomRewardedVideo


- (instancetype)initWithRewardBasedVideoAdNetworkConnector:
(id<GADMRewardBasedVideoAdNetworkConnector>)connector {
    if (!connector) {
        return nil;
    }
    
    self = [super init];
    if (self) {
       _rewardBasedVideoAdConnector = connector;
        
        NSString *serverParam = [connector.credentials objectForKey:GADCustomEventParametersServer];
        if (serverParam != nil && serverParam.length > 0)
        {
            NSError *jsonError;
            NSData *objectData = [serverParam dataUsingEncoding:NSUTF8StringEncoding];
            NSDictionary *json = [NSJSONSerialization JSONObjectWithData:objectData
                                                                 options:NSJSONReadingMutableContainers
                                                                   error:&jsonError];
            
            pokktScreenName = [json objectForKey:@"POKKT_SCREEN_NAME"];
            appId = [json objectForKey:@"POKKT_APP_ID"];
            securityKey = [json objectForKey:@"POKKT_SEC_KEY"];
            isDebug = [[json objectForKey:@"POKKT_DEBUG"] boolValue];
            thirdPartyId = [json objectForKey:@"POKKT_THIRD_PARTY_USERID"];
        }
       
    }
    return self;
}

- (void)setUp
{
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // [optional] set it to true if you want to enable logs for PokktSDK
    [PokktDebugger setDebug:isDebug];
    
    [PokktAds setThirdPartyUserId:thirdPartyId];
    
    // OPTIONAL but we SUGGEST you to implement delegates as it will help you to determine the status of your request
    
    [PokktVideoAds setPokktVideoAdsDelegate:self];
    
    [PokktVideoAds cacheRewarded:pokktScreenName];
}

- (void)requestRewardBasedVideoAd
{
    [PokktVideoAds cacheRewarded:pokktScreenName];
}

- (void)presentRewardBasedVideoAdWithRootViewController:(UIViewController *)viewController
{
    [PokktVideoAds showRewarded:pokktScreenName withViewController:viewController];
}

- (void)stopBeingDelegate
{
   
}

- (void)adapterDidSetUpRewardBasedVideoAd:
(id<GADMRewardBasedVideoAdNetworkAdapter>)rewardBasedVideoAdAdapter
{
    NSLog(@"Adapter setup successfully");
}

- (void)adapter:(id<GADMRewardBasedVideoAdNetworkAdapter>)rewardBasedVideoAdAdapter
didFailToSetUpRewardBasedVideoAdWithError:(NSError *)error
{
    NSLog(@"%@",error.description);
}


#pragma mark Pokkt Video Ads Delegates

- (void)videoAdCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
{
    id<GADMRewardBasedVideoAdNetworkConnector> strongConnector = _rewardBasedVideoAdConnector;
    
    [strongConnector adapterDidReceiveRewardBasedVideoAd:self];
}

- (void)videoAdCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
    id<GADMRewardBasedVideoAdNetworkConnector> strongConnector = _rewardBasedVideoAdConnector;
    
    NSError *err = [NSError errorWithDomain:@"Error"
                                       code:0
                                   userInfo:@{
                                              NSLocalizedDescriptionKey:errorMessage
                                              }];

    [strongConnector adapter:self didFailToLoadRewardBasedVideoAdwithError:err];
}

- (void)videoAdDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
    id<GADMRewardBasedVideoAdNetworkConnector> strongConnector = _rewardBasedVideoAdConnector;
     [strongConnector adapterDidOpenRewardBasedVideoAd:self];
}

- (void)videoAdGratified: (NSString *)screenName reward:(float)reward
{
    id<GADMRewardBasedVideoAdNetworkConnector> strongConnector = _rewardBasedVideoAdConnector;
    
    GADAdReward *GadReward = [[GADAdReward alloc] initWithRewardType:@"Coin" rewardAmount:[[NSDecimalNumber alloc] initWithFloat:reward]];
    [strongConnector adapter:self didRewardUserWithReward:GadReward];
}

- (void)videoAdClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
{
    id<GADMRewardBasedVideoAdNetworkConnector> strongConnector = _rewardBasedVideoAdConnector;
     [strongConnector adapterDidCloseRewardBasedVideoAd:self];
}

- (void)videoAdFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
{
}

- (void)videoAdSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
}

- (void)videoAdCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
{
}


@end
